# Example project for django-icons

This example project only supports the latest version of Django.

## Instructions

To run the example:

```bash
git clone https://github.com/zostera/django-icons.git

cd django-icons/example
pip install -r requirements.txt
python manage.py migrate
python manage.py runserver
```

Server should be live at http://127.0.0.1:8000/ now.